@@ -1,4 +1,4 @@
 # -*- coding: utf-8 -*-
 """Controllers for the tgapp-registration pluggable application."""
 
-from root import RootController
\ No newline at end of file
+from .root import RootController
